@@ -12,11 +12,12 @@ from circlevis.replay_info import ReplayInfo
 
 class Interface(QWidget):
     def __init__(self, beatmap_info, replays, events, library, speeds, \
-        start_speed, paint_info, statistic_functions):
+        start_speed, paint_info, statistic_functions, snaps_args):
         super().__init__()
         self.speeds = speeds
         self.replays = replays
         self.library = library
+        self.snaps_args = snaps_args
         self.current_replay_info = None
         # maps `circleguard.Replay` to `circlevis.ReplayInfo`, as its creation
         # is relatively expensive and users might open and close the same info
@@ -37,20 +38,19 @@ class Interface(QWidget):
         cg_statistics_worked.daemon = True
         cg_statistics_worked.start()
 
+        # create our own library in a temp dir if one wasn't passed
+        if not self.library:
+            # keep a reference so it doesn't get deleted
+            self.temp_dir = TemporaryDirectory()
+            self.library = Library(self.temp_dir.name)
+
         self.beatmap = None
         if beatmap_info.path:
             self.beatmap = Beatmap.from_path(beatmap_info.path)
         elif beatmap_info.map_id:
-            # library is nullable - None means we define our own (and don't care about saving)
             # TODO move temporary directory creation to slider probably, since
             # this logic is now duplicated here and in circlecore
-            if library:
-                self.beatmap = library.lookup_by_id(beatmap_info.map_id, download=True, save=True)
-            else:
-                # keep a reference so it doesn't get deleted
-                self.temp_dir = TemporaryDirectory()
-                self.library = Library(self.temp_dir.name)
-                self.beatmap = self.library.lookup_by_id(beatmap_info.map_id, download=True, save=True)
+            self.beatmap = self.library.lookup_by_id(beatmap_info.map_id, download=True, save=True)
 
 
         self.renderer = Renderer(self.beatmap, replays, events, library, \
@@ -180,7 +180,7 @@ class Interface(QWidget):
             replay_info.show()
         else:
             ur, frametime, snaps, edge_hits = self.replay_statistics_precalculated[replay]
-            replay_info = ReplayInfo(replay, self.beatmap, self.library.path, ur, frametime, snaps, edge_hits)
+            replay_info = ReplayInfo(replay, self.beatmap, self.library.path, ur, frametime, snaps, edge_hits, self.snaps_args)
             replay_info.seek_to.connect(self.renderer.seek_to)
 
         # don't show two of the same info panels at once
@@ -204,10 +204,14 @@ class Interface(QWidget):
     def calculate_cg_statistics(self):
         cg = KeylessCircleguard()
         for replay in self.replays:
-            ur = cg.ur(replay)
+            ur = None
+            edge_hits = None
+            if replay.map_info.available():
+                ur = cg.ur(replay)
+                edge_hits = cg.hits(replay, within=ReplayInfo.EDGE_HIT_THRESH)
+
             frametime = cg.frametime(replay)
-            snaps = cg.snaps(replay)
-            edge_hits = cg.hits(replay, within=ReplayInfo.EDGE_HIT_THRESH)
+            snaps = cg.snaps(replay, **self.snaps_args)
             self.replay_statistics_precalculated[replay] = (ur, frametime, snaps, edge_hits)
 
 
