@@ -68,12 +68,11 @@ class Renderer(QFrame):
         # beatmap init stuff
         self.hitobjs_to_draw = []
 
+        use_hr = any([Mod.HR in replay.mods for replay in replays])
         if beatmap:
-            self.hit_objects = beatmap.hit_objects()
+            self.hit_objects = beatmap.hit_objects(hard_rock=use_hr)
             self.playback_len = self.get_hit_endtime(self.hit_objects[-1])
-            # for now we'll use the hr or dt modified cs, ar, and od if any
-            # replay has HR enabled
-            use_hr = any([Mod.HR in replay.mods for replay in replays])
+
             ar = beatmap.ar(hard_rock=use_hr)
             # https://osu.ppy.sh/help/wiki/Beatmapping/Approach_rate for formulas
             if ar <= 5:
@@ -115,11 +114,13 @@ class Renderer(QFrame):
                 Player(replay=replay,
                        pen=QPen(QColor().fromHslF(i / self.num_replays, 0.75, 0.5)),))
         self.playback_len = max(max(player.t) for player in self.players) if self.num_replays > 0 else self.playback_len
-        # flip all replays with hr
-        for player in self.players:
-            if Mod.HardRock in player.mods:
-                for d in player.xy:
-                    d[1] = 384 - d[1]
+        # if our hitobjs are hard_rock versions, flip any player *without* hr
+        # so they match other hr players.
+        if use_hr:
+            for player in self.players:
+                if Mod.HardRock not in player.mods:
+                    for d in player.xy:
+                        d[1] = 384 - d[1]
 
         # clock stuff
         self.clock = Timer(start_speed)
